import NormalButton from "@/components/normalButton"
import Popup from "@/components/popup"
import { View } from "@tarojs/components"
import classnames from "classnames"
import styles from './index.module.scss'
import { FC, memo, useEffect, useState } from 'react'
import Search from "@/components/search"
import IconFont from "@/components/iconfont/iconfont"
import {EnumDeliveryNoticeTypeList} from '@/api/index'

type SearchFilter = {
  type?: number
}

const scanIcon = () => {
  // 扫描
  const handleScan = () => {}
  return (
    <View onClick={handleScan} className={styles.scanHandler}>
      <IconFont name='icon-saomiao' size={40}></IconFont>
    </View>
  )
}

const DeliveryFilter: FC = memo(() => {

  const {fetchData} = EnumDeliveryNoticeTypeList()

  const [searchFilter, useSearchFilter] = useState<SearchFilter>({
    
  })
  const handleSelectedType = (type: string | number) => {
    if (typeof type === 'string' && type === 'default') {
      // setSearch((e) => ({ ...e }))
    } else {
      // setSearch((e) => ({ ...e, type: type as number }))
    }
  }

  const handleSearchBarChange = () => {}

  useEffect(() => {
    getEnumData()
  
  }, [])
  

  const [typeList, setTypeList] = useState<{id: number, name: string}[]>()

  const getEnumData = async () => {
    const res = await fetchData()
    setTypeList(res.data.list)
  }
  

  return (
    <>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>发货类型</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--type'])}>
          <NormalButton
            type={searchFilter.type == null ? 'primary' : 'info'}
            plain={searchFilter.type === null}
            circle
            customClassName={classnames(styles.filterTypeButton)}
            customTextClassName={searchFilter.type === null && styles.filterTypeText}
            onClick={() => handleSelectedType('default')}>
            不限
          </NormalButton>
          {!!typeList?.length && typeList?.map(item => {
            return (
              <NormalButton
                type={searchFilter.type === item?.id ? 'primary' : 'info'}
                plain={searchFilter.type !== item?.id}
                circle
                customClassName={styles.filterTypeButton}
                customTextClassName={searchFilter.type === item?.id && styles.filterTypeText}
                onClick={() => handleSelectedType(item?.id)}>
                {item.name}
              </NormalButton>
            )
          })}
          {/* <NormalButton
            type={searchFilter.type === 0 ? 'primary' : 'info'}
            plain={searchFilter.type !== 0}
            circle
            customClassName={styles.filterTypeButton}
            customTextClassName={searchFilter.type === 0 && styles.filterTypeText}
            onClick={() => handleSelectedType(1)}>
            销售发货单
          </NormalButton>
          <NormalButton
            type={searchFilter.type === 0 ? 'primary' : 'info'}
            plain={searchFilter.type !== 0}
            circle
            customClassName={styles.filterTypeButton}
            customTextClassName={searchFilter.type === 1 && styles.filterTypeText}
            onClick={() => handleSelectedType(2)}>
            调拨发货单
          </NormalButton>
          <NormalButton
            type={searchFilter.type === 0 ? 'primary' : 'info'}
            plain={searchFilter.type !== 0}
            circle
            customClassName={styles.filterTypeButton}
            customTextClassName={searchFilter.type === 2 && styles.filterTypeText}
            onClick={() => handleSelectedType(3)}>
            采购退货单
          </NormalButton> */}
        </View>
      </View>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>发货单号</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--inputBar'])}>
          <Search
            placeholder='请输入或扫描条形码'
            showBtn={false}
            changeOnSearch={handleSearchBarChange}
            debounceTime={300}
            customRightSlot={scanIcon()}></Search>
        </View>
      </View>
      <View className={styles.filterItem}>
        <View className={styles['filterItem--title']}>查询日期</View>
        <View className={classnames(styles['filterItem--wrapper'], styles['filter--time'])}>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            不限
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            今天
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            昨日
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            近7日
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            近30日
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTypeButton}>
            近90日
          </NormalButton>
          <NormalButton type='primary' circle customClassName={styles.filterTimeButton}>
            自定义起始时间{<IconFont name='icon-chakanquanbukehu' size={60}></IconFont>}
          </NormalButton>
        </View>
      </View>
    </>
  )
})
export default DeliveryFilter
