import { View, Text } from '@tarojs/components'
import { useCallback, useEffect, useMemo, useRef, useState, FC, memo } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import Search from '@/components/search'
import { DeliverNoticeOrderList, EnumSaleorderStatus } from '@/api/index'
import Taro from '@tarojs/taro'
import { useRouter } from '@tarojs/taro'
import InfiniteScroll from '@/components/infiniteScroll'
import { dataLoadingStatus, getFilterData } from '@/common/util'
import IconText from '@/components/iconText'
import IconFont from '@/components/iconfont/iconfont'
import ItemList from './components/ItemList'
import DeliveryStatusList from './components/DeliveryStatusList'
import Popup from '@/components/popup'
import DeliveryFilter from './components/Filter'

type SearchData = {
  delivery_notice_order_no?: string // 发货单号
  delivery_notice_order_status?: number | string // 发货状态
  date_min?: string // 开始时间
  date_max?: string // 结束时间
  type?: number // 发货类型
  page: number
  size: number
}

const scanIcon = () => {
  // 扫描
  const handleScan = () => {}
  return (
    <View onClick={handleScan} className={styles.scanHandler}>
      <IconFont name='icon-saomiao' size={40}></IconFont>
    </View>
  )
}

// 发货列表
const Delivery: FC = () => {
  const [search, setSearch] = useState<SearchData>({
    delivery_notice_order_status: 0, // 待发货
    page: 1,
    size: 10,
  })
  const [deliveryOrderList, setDeliveryOrderList] = useState<{ list: any[]; total: number }>({ list: [], total: 0 })

  const { fetchData: FetchDeliveryOrderList, state: orderState } = DeliverNoticeOrderList()
  //数据加载状态
  const statusMore = useMemo(() => {
    return dataLoadingStatus({ list: deliveryOrderList.list, total: deliveryOrderList.total, status: orderState.loading })
  }, [deliveryOrderList, orderState])

  // const [clientObj, setclientObj] = useState({
  //   clientId: null,
  //   clientName: '',
  // })

  //输入搜索关键字
  const getSearchData = useCallback((searchValue: string) => {
    console.log('searchValue==>', searchValue)
    // pageNum.current.page = 1
    // setClientlist(() => ({ list: [], total: 0 }))
    // setSearch((e) => ({ ...e, name: eq, size: 10 }))
  }, [])

  // const router = useRouter()

  useEffect(() => {
    console.log('useEffect ===> search', search)
    if (search.delivery_notice_order_no === '') {
      setSearch((e) => ({ ...e, delivery_notice_order_no: undefined }))
    }
    if (search.delivery_notice_order_no !== '') getData()
  }, [search])

  //上拉加载数据
  const pageNum = useRef({ size: search.size, page: search.page })

  const getScrollToLower = useCallback(() => {
    if (deliveryOrderList.list.length < deliveryOrderList.total) {
      pageNum.current.page++
      const size = pageNum.current.size * pageNum.current.page
      setSearch((e) => ({ ...e, size }))
      console.log(search, 11111)
    }
  }, [deliveryOrderList])

  //列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)
  const getRefresherRefresh = async () => {
    pageNum.current.size = 1
    setRefresherTriggeredStatus(true)
    setSearch((val) => ({ ...val, size: 10 }))
  }
  const getData = async () => {
    const res = await FetchDeliveryOrderList(getFilterData(search))
    // if (router?.params.clientId) {
    //   res.data.list.map((item) => {
    //     if (item.id == router?.params.clientId) {
    //       item.checked = true
    //     } else {
    //       item.checked = false
    //     }
    //     return item
    //   })
    // }
    setDeliveryOrderList((e) => ({ ...e, list: res.data?.list, total: res.data?.total }))
    setRefresherTriggeredStatus(() => false)
  }

  // //选择客户
  // const selectClient = (item) => {
  //   clentList.list.map((it) => {
  //     if (item.id === it.id) {
  //       it.checked = true
  //     } else {
  //       it.checked = false
  //     }
  //     return it
  //   })
  //   setclientObj(item)
  //   let pages = Taro.getCurrentPages() // 获取当前的页面栈
  //   let prevPage = pages[pages.length - 2]
  //   prevPage.setData({
  //     //设置上一个页面的值
  //     clientId: item.id,
  //     clientName: item.name,
  //   })
  //   setClientlist((e) => ({ ...e, list: clentList?.list, total: clentList?.total }))
  //   Taro.navigateBack({
  //     delta: 1,
  //   })
  // }
  // useEffect(() => {
  //   if (clientObj?.clientId !== null) {
  //     setclientObj(clientObj)
  //   } else {
  //     let pages = Taro.getCurrentPages() // 获取当前的页面栈
  //     let prevPage = pages[pages.length - 2]
  //     prevPage.setData({
  //       //设置上一个页面的值
  //       clientId: '',
  //       clientName: '',
  //     })
  //   }
  // }, [clientObj])

  const handleChangeFilterData = () => {}

  const [currentStatus, setCurrentStatus] = useState('待发货')

  const handleChangeStatus = ({ id: statusId, name: statusName }) => {
    let fuckingBadCodeId: string | number = 0
    if (statusId === 3) {
      fuckingBadCodeId = 0
    } else if (statusId === 4) {
      fuckingBadCodeId = '1,2'
    }
    setCurrentStatus(statusName)
    setSearch((e) => ({ ...e, delivery_notice_order_status: fuckingBadCodeId }))
    getData()
  }

  const handleAuditSuccess = () => {
    getData()
  }

  const [showFilter, setShowFilter] = useState(false)
  // 筛选列表
  const onShowFilter = () => {
    setShowFilter(true)
  }


  

  return (
    <View className={styles.delivery}>
      <View className={styles.searchBox}>
        <Search placeholder='请输入或扫描条形码' showBtn={false} changeOnSearch={getSearchData} debounceTime={300} customRightSlot={scanIcon()}>
          <View onClick={onShowFilter} className={styles.icon__filter}>
            <IconText iconName='icon-shaixuan' text='筛选' customClass={styles['icon--filter']} />
          </View>
        </Search>
      </View>
      {/* 状态栏 */}
      <DeliveryStatusList onChangeStatus={handleChangeStatus}></DeliveryStatusList>

      <View className={styles.listBox}>
        <InfiniteScroll
          statusMore={statusMore}
          selfonScrollToLower={getScrollToLower}
          refresherEnabled={true}
          refresherTriggered={refresherTriggeredStatus}
          selfOnRefresherRefresh={getRefresherRefresh}>
          <Text className={styles['listBox--total']}>
            {currentStatus}共 {deliveryOrderList.total} 单
          </Text>
          {deliveryOrderList.list.map((item, index) => {
            return <ItemList itemData={item} key={item.id} onSuccess={handleAuditSuccess}></ItemList>
          })}
        </InfiniteScroll>
      </View>
      <Popup show={showFilter} title='筛选列表'>
        <DeliveryFilter />
      </Popup>
    </View>
  )
}

export default Delivery
